==> certmanager-model-v1alpha2-6.2.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01IngressTemplateFluentImpl<A extends ACMEChallengeSolverHTTP01IngressTemplateFluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverHTTP01IngressTemplateFluent<A>{
  public ACMEChallengeSolverHTTP01IngressTemplateFluentImpl() {
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluentImpl(ACMEChallengeSolverHTTP01IngressTemplate instance) {
    this.withMetadata(instance.getMetadata()); 
  }
  private ACMEChallengeSolverHTTP01IngressObjectMetaBuilder metadata;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01IngressObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ACMEChallengeSolverHTTP01IngressObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ACMEChallengeSolverHTTP01IngressObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluent.MetadataNested<A> withNewMetadata() {
    return new ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.MetadataNestedImpl();
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluent.MetadataNested<A> withNewMetadataLike(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
    return new ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.MetadataNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder().build());
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluent.MetadataNested<A> editOrNewMetadataLike(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEChallengeSolverHTTP01IngressTemplateFluentImpl that = (ACMEChallengeSolverHTTP01IngressTemplateFluentImpl) o;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl<ACMEChallengeSolverHTTP01IngressTemplateFluent.MetadataNested<N>> implements ACMEChallengeSolverHTTP01IngressTemplateFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressObjectMetaBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01IngressTemplateFluentImpl<A extends ACMEChallengeSolverHTTP01IngressTemplateFluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverHTTP01IngressTemplateFluent<A>{
  public ACMEChallengeSolverHTTP01IngressTemplateFluentImpl() {
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluentImpl(ACMEChallengeSolverHTTP01IngressTemplate instance) {
    if (instance != null) {
      this.withMetadata(instance.getMetadata());
    }
  }
  private ACMEChallengeSolverHTTP01IngressObjectMetaBuilder metadata;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01IngressObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ACMEChallengeSolverHTTP01IngressObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ACMEChallengeSolverHTTP01IngressObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.MetadataNestedImpl();
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.MetadataNested<A> withNewMetadataLike(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
    return new ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.MetadataNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder().build());
  }
  public ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.MetadataNested<A> editOrNewMetadataLike(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01IngressTemplateFluentImpl that = (ACMEChallengeSolverHTTP01IngressTemplateFluentImpl) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressObjectMetaFluentImpl<ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.MetadataNested<N>> implements ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ACMEChallengeSolverHTTP01IngressObjectMeta item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressObjectMetaBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressObjectMetaBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressTemplateFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  
}
